# osu! wiki tools

A collection of various tools that may be useful for [osu! wiki](https://osu.ppy.sh/wiki/) contributors

## Testing

```
python3 -m venv ./venv
source ./venv/bin/activate
pip install -r requirements.txt
pytest --mypy
```
